<?php

namespace Drupal\commerce_cardpointe\PluginForm\HostedIframe;

use Drupal\commerce_payment\PluginForm\PaymentMethodAddForm as BasePaymentMethodAddForm;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;

/**
 * Provides the HostedIframe payment method add form.
 */
class PaymentMethodAddForm extends BasePaymentMethodAddForm {

  /**
   * {@inheritdoc}
   */
  public function buildCreditCardForm(array $element, FormStateInterface $form_state) {
    $element['#attached']['library'][] = 'commerce_cardpointe/hosted-iframe';
    /** @var \Drupal\commerce_cardpointe\Plugin\Commerce\PaymentGateway\HostedIframeInterface $plugin */
    $plugin = $this->plugin;
    $configuration = $plugin->getConfiguration();

    $css = '
      .error{
        color:red;
      }
      label{
        font-size:1.1em;
        font-weight: 700;
      }
      input{
        padding: 0.5rem 0.75rem;
        width: 90%;
        margin:10px 0;
      }
      select{
        padding: 0.5rem 0.75rem;
        width:20%;
        margin:10px 0;
      }';
    $api_url = $plugin->getApiUrl($configuration['site'], $configuration['mode']);
    $token_frame_url = Url::fromUri($api_url . '/itoke/ajax-tokenizer.html', [
      'query' => [
        'useexpiry' => 'true',
        'usecvv' => 'true',
        'formatinput' => 'true',
        'css' => $css,
      ],
    ])->toString();
    $element['#attributes']['class'][] = 'cardpointe-form';
    // Drupal 10.1.0 now supports #type iframe, but for compatability,
    // we will continue to use html_tag.
    $element['token_frame'] = [
      '#type' => 'html_tag',
      '#tag' => 'iframe',
      '#attributes' => [
        'src' => $token_frame_url,
        'frameborder' => '0',
        'scrolling' => 'no',
        'height' => '230px',
        'width' => '66%',
      ],
    ];
    $element['token'] = [
      '#type' => 'hidden',
      '#attributes' => [
        'id' => ['token'],
      ],
    ];
    $element['expiration'] = [
      '#type' => 'hidden',
      '#attributes' => [
        'id' => ['expiration'],
      ],
    ];
    $element['reuse_payment_method'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Save payment method'),
      '#description' => $this->t('If enabled, ensure your payment terms indicate credit card data will be encrypted by a third party and made available for reuse in your payment forms.'),
      '#default_value' => TRUE,
      // Saves a payment method without consent on the add payment method page.
      '#disabled' => \Drupal::routeMatch()->getRouteName() == 'entity.commerce_payment_method.add_form',
    ];

    return $element;
  }

  /**
   * {@inheritdoc}
   */
  protected function validateCreditCardForm(array &$element, FormStateInterface $form_state) {
    // The payment gateway plugin will validate the payment details.
  }

  /**
   * {@inheritdoc}
   */
  public function submitCreditCardForm(array $element, FormStateInterface $form_state) {
    // The payment gateway plugin will process the submitted payment details.
  }

}
